from xlavm_lib.visual_test.visual_test import VisualTest
from xlavm_lib.visual_test.visual_test_report import VisualTestReport
from xlavm_lib.get_ids.get_ids import GetIds
from xlavm_lib.allure_report.allure_report import AllureReport

__all__ = [
    "VisualTest",
    "VisualTestReport",
    "GetIds",
    "AllureReport"
]

# Asi el usuario usa: from xlavm_lib import VisualTest, VisualTestReport, GetIds, AllureReport
